@@ -169,7 +169,7 @@ class Dense_cdopt(Module):
     C = lambda kernel : manifold.C(weight_to_var(kernel))
     quad_penalty = jnp.sum( C(kernel) **2  )
 
-    kernel = var_to_weight( manifold.Init_point(Xinit = weight_to_var(kernel)))
+    # kernel = var_to_weight( manifold.Init_point(Xinit = weight_to_var(kernel)))
 #     self.quad_penalty = lambda kernel: manifold.C_quad_penalty(weight_to_var(kernel))
 
     y = lax.dot_general(inputs, A(kernel),
@@ -389,7 +389,7 @@ class _Conv_cdopt(Module):
     A = lambda kernel : var_to_weight( manifold.A(weight_to_var(kernel)))
     C = lambda kernel : manifold.C(weight_to_var(kernel))
     quad_penalty = jnp.sum( C(kernel) **2  )
-    kernel = var_to_weight( manifold.Init_point(Xinit = weight_to_var(kernel)))
+    # kernel = var_to_weight( manifold.Init_point(Xinit = weight_to_var(kernel)))
     
     if self.shared_weights:
       y = lax.conv_general_dilated(
@@ -521,7 +521,7 @@ class ConvTranspose_cdopt(Module):
     A = lambda kernel : var_to_weight( manifold.A(weight_to_var(kernel)))
     C = lambda kernel : manifold.C(weight_to_var(kernel))
     quad_penalty = jnp.sum( C(kernel) **2  )
-    kernel = var_to_weight( manifold.Init_point(Xinit = weight_to_var(kernel)))
+    # kernel = var_to_weight( manifold.Init_point(Xinit = weight_to_var(kernel)))
     y = lax.conv_transpose(
         inputs,
         A(kernel),
